AreaChartPainter class

Inheritance

Constructors

AreaChartPainter(List<AreaChartSeries> series, {required List xAxis, int? touchedIndex, TextStyle? xAxisLabelStyle, String xAxisLabelFormatter(dynamic label)?, TextStyle? yAxisLabelStyle, String yAxisLabelFormatter(double value)?, bool showGrid = true, double yAxisMargin = 40, double xAxisMargin = 30})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
series List<AreaChartSeries>
final
showGrid bool
final
touchedIndex int?
final
xAxis List
final
xAxisLabelFormatter String Function(dynamic label)?
final
xAxisLabelStyle TextStyle?
final
xAxisMargin double
final
yAxisLabelFormatter String Function(double value)?
final
yAxisLabelStyle TextStyle?
final
yAxisMargin double
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant AreaChartPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited