LineChart class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LineChart
Constructors
-
LineChart({Key? key, required List<
LineChartSeries> series, double spacing = 20, String? title, TextStyle? titleStyle, TextStyle? xAxisLabelStyle, TextStyle? yAxisLabelStyle, String yAxisLabelFormatter(double value)?, String xAxisLabelFormatter(dynamic label)?, void onPointTap(LineChartData)?, double yAxisMargin = 30, double xAxisMargin = 30, bool showDots = true, bool showGrid = true, String lineTooltipBuilder(LineChartSeries serie, LineChartData data)?, double dotRadius = 4.0, double strokeWidth = 2.0, required List xAxis, double? yMin, double? yMax}) -
const
Properties
- dotRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineTooltipBuilder → String Function(LineChartSeries serie, LineChartData data)?
-
final
- onPointTap → void Function(LineChartData)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
LineChartSeries> -
final
- showDots → bool
-
final
- showGrid → bool
-
final
- spacing → double
-
final
- strokeWidth → double
-
final
- title → String?
-
final
- titleStyle → TextStyle?
-
final
- xAxis → List
-
final
- xAxisLabelFormatter → String Function(dynamic label)?
-
final
- xAxisLabelStyle → TextStyle?
-
final
- xAxisMargin → double
-
final
- yAxisLabelFormatter → String Function(double value)?
-
final
- yAxisLabelStyle → TextStyle?
-
final
- yAxisMargin → double
-
final
- yMax → double?
-
final
- yMin → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LineChart> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited